<?php
// creature_quest_loot.php

// Check if the request comes from localhost (IPv4 or IPv6)
if ($_SERVER['REMOTE_ADDR'] !== '127.0.0.1' && $_SERVER['REMOTE_ADDR'] !== '::1') {
    // Terminate the script if the request is not from localhost
    die('Access denied.');
}

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Start session to retrieve DB credentials
session_start();

// Get DB credentials from session or previous page
$ip = $_SESSION['db_ip'] ?? $_GET['ip'] ?? '';
$user = $_SESSION['db_user'] ?? $_GET['user'] ?? '';
$password = $_SESSION['db_password'] ?? $_GET['password'] ?? '';
$dbname = $_SESSION['db_name'] ?? $_GET['dbname'] ?? '';
$port = $_SESSION['db_port'] ?? $_GET['port'] ?? '';


echo "<pre>";
echo "IP: " . $ip . "\n";
echo "Port: " . $port . "\n";
echo "User: " . $user . "\n";
echo "Password: " . $password . "\n";
echo "DB Name: " . $dbname . "\n";
echo "</pre>";


// Connect to the database
$conn = new mysqli($ip, $user, $password, $dbname, $port);
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Initialize variables
$creatureLoot = [];
$conditions = [];
$errors = [];
$success = "";

// Get the ID from the previous page
if (isset($_GET['id'])) {
    $id = intval($_GET['id']);
} else {
    die("No ID provided.");
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Determine action: Save or Delete
    if (isset($_POST['save'])) {
        // Retrieve and sanitize inputs for creature_loot_template
        $entry = intval($_POST['Entry']);
        $item = intval($_POST['Item']);
        $chance = floatval($_POST['ChanceOrQuestChance']);
        $lootMode = intval($_POST['LootMode']);
        $groupId = intval($_POST['GroupId']);
        $minCount = intval($_POST['MinCountOrRef']);
        $maxCount = intval($_POST['MaxCount']);
        $comments = $conn->real_escape_string($_POST['Comments']);

        // Retrieve and sanitize inputs for conditions
        $sourceType = intval($_POST['SourceTypeOrReferenceId']);
        $sourceGroup = intval($_POST['SourceGroup']);
        $sourceEntry = intval($_POST['SourceEntry']);
        $sourceId = intval($_POST['SourceId']);
        $elseGroup = intval($_POST['ElseGroup']);
        $conditionType = intval($_POST['ConditionTypeOrReference']);
        $conditionTarget = intval($_POST['ConditionTarget']);
        $conditionValue1 = intval($_POST['ConditionValue1']);
        $conditionValue2 = intval($_POST['ConditionValue2']);
        $conditionValue3 = intval($_POST['ConditionValue3']);
        $negativeCondition = intval($_POST['NegativeCondition']);
        $errorTextId = intval($_POST['ErrorTextId']);
        $scriptName = $conn->real_escape_string($_POST['ScriptName']);
        $conditionComments = $conn->real_escape_string($_POST['ConditionComments']);

        // Check if record exists
        $checkQuery = "SELECT * FROM creature_loot_template WHERE entry = $entry AND item = $item";
        $result = $conn->query($checkQuery);

        if ($result->num_rows > 0) {
            // Update existing record
            $updateQuery = "UPDATE creature_loot_template SET 
                                ChanceOrQuestChance = $chance,
                                LootMode = $lootMode,
                                GroupId = $groupId,
                                MinCountOrRef = $minCount,
                                MaxCount = $maxCount,
                                Comments = '$comments'
                            WHERE entry = $entry AND item = $item";
            if ($conn->query($updateQuery) === TRUE) {
                $success = "creature_loot_template updated successfully.";
            } else {
                $errors[] = "Error updating creature_loot_template: " . $conn->error;
            }

            // Update conditions
            $updateConditions = "UPDATE conditions SET 
                                    SourceTypeOrReferenceId = $sourceType,
                                    SourceGroup = $sourceGroup,
                                    SourceEntry = $sourceEntry,
                                    SourceId = $sourceId,
                                    ElseGroup = $elseGroup,
                                    ConditionTypeOrReference = $conditionType,
                                    ConditionTarget = $conditionTarget,
                                    ConditionValue1 = $conditionValue1,
                                    ConditionValue2 = $conditionValue2,
                                    ConditionValue3 = $conditionValue3,
                                    NegativeCondition = $negativeCondition,
                                    ErrorTextId = $errorTextId,
                                    ScriptName = '$scriptName',
                                    Comments = '$conditionComments'
                                WHERE SourceGroup = $sourceGroup AND SourceEntry = $sourceEntry";
            if ($conn->query($updateConditions) === TRUE) {
                $success .= " conditions updated successfully.";
            } else {
                $errors[] = "Error updating conditions: " . $conn->error;
            }
        } else {
            // Insert new record
            $insertQuery = "INSERT INTO creature_loot_template 
                            (entry, item, ChanceOrQuestChance, LootMode, GroupId, MinCountOrRef, MaxCount, Comments)
                            VALUES 
                            ($entry, $item, $chance, $lootMode, $groupId, $minCount, $maxCount, '$comments')";
            if ($conn->query($insertQuery) === TRUE) {
                $success = "creature_loot_template inserted successfully.";
            } else {
                $errors[] = "Error inserting creature_loot_template: " . $conn->error;
            }

            // Insert conditions
            $insertConditions = "INSERT INTO conditions 
                                (SourceTypeOrReferenceId, SourceGroup, SourceEntry, SourceId, ElseGroup, 
                                ConditionTypeOrReference, ConditionTarget, ConditionValue1, ConditionValue2, 
                                ConditionValue3, NegativeCondition, ErrorTextId, ScriptName, Comments)
                                VALUES
                                ($sourceType, $sourceGroup, $sourceEntry, $sourceId, $elseGroup, 
                                $conditionType, $conditionTarget, $conditionValue1, $conditionValue2, 
                                $conditionValue3, $negativeCondition, $errorTextId, '$scriptName', '$conditionComments')";
            if ($conn->query($insertConditions) === TRUE) {
                $success .= " conditions inserted successfully.";
            } else {
                $errors[] = "Error inserting conditions: " . $conn->error;
            }
        }
    } elseif (isset($_POST['delete'])) {
        // Handle deletion
        $entry = intval($_POST['Entry']);
        $item = intval($_POST['Item']);

        // Delete from conditions first due to foreign key constraints (if any)
        $deleteConditions = "DELETE FROM conditions WHERE SourceGroup = $entry AND SourceEntry = $item";
        if ($conn->query($deleteConditions) === TRUE) {
            // Delete from creature_loot_template
            $deleteLoot = "DELETE FROM creature_loot_template WHERE entry = $entry AND item = $item";
            if ($conn->query($deleteLoot) === TRUE) {
                $success = "Record deleted successfully.";
            } else {
                $errors[] = "Error deleting from creature_loot_template: " . $conn->error;
            }
        } else {
            $errors[] = "Error deleting from conditions: " . $conn->error;
        }
    }
}

// Fetch existing data to populate the form
// Fetch creature_loot_template
$lootQuery = "SELECT * FROM creature_loot_template WHERE entry = $id";
$lootResult = $conn->query($lootQuery);
if ($lootResult->num_rows > 0) {
    $creatureLoot = $lootResult->fetch_assoc();
}

// Fetch conditions
$conditionsQuery = "SELECT * FROM conditions 
                    WHERE ConditionValue1 = $id";
$conditionsResult = $conn->query($conditionsQuery);
if ($conditionsResult->num_rows > 0) {
    // Assuming one condition per creature_loot_template
    $conditions = $conditionsResult->fetch_assoc();
}

$conn->close();
?>

<!DOCTYPE html>
<html>
<head>
    <title>Creature Quest Loot</title>
    <style>
        body { font-family: Arial, sans-serif; }
        .container { width: 90%; margin: auto; }
        .section { margin-bottom: 30px; }
        label { display: block; margin-top: 10px; }
        input[type="text"], select, textarea { width: 100%; padding: 8px; }
        .buttons { margin-top: 20px; }
        .buttons input { padding: 10px 20px; }
        .messages { margin-top: 20px; }
        .messages .error { color: red; }
        .messages .success { color: green; }
    </style>
    <script>
        function openSearch() {
            window.open('quest_loot_search.php?id=<?php echo $id; ?>', 'SearchExisting', 'width=600,height=400');
        }

        // Function to populate fields from search
        function populateFields(data) {
            // Populate creature_loot_template fields
            document.getElementById('Entry').value = data.entry;
            document.getElementById('Item').value = data.item;
            document.getElementById('ChanceOrQuestChance').value = data.ChanceOrQuestChance;
            document.getElementById('LootMode').value = data.LootMode;
            document.getElementById('GroupId').value = data.GroupId;
            document.getElementById('MinCountOrRef').value = data.MinCountOrRef;
            document.getElementById('MaxCount').value = data.MaxCount;
            document.getElementById('Comments').value = data.Comments;

            // Populate conditions fields
            document.getElementById('SourceTypeOrReferenceId').value = data.SourceTypeOrReferenceId;
            document.getElementById('SourceGroup').value = data.SourceGroup;
            document.getElementById('SourceEntry').value = data.SourceEntry;
            document.getElementById('SourceId').value = data.SourceId;
            document.getElementById('ElseGroup').value = data.ElseGroup;
            document.getElementById('ConditionTypeOrReference').value = data.ConditionTypeOrReference;
            document.getElementById('ConditionTarget').value = data.ConditionTarget;
            document.getElementById('ConditionValue1').value = data.ConditionValue1;
            document.getElementById('ConditionValue2').value = data.ConditionValue2;
            document.getElementById('ConditionValue3').value = data.ConditionValue3;
            document.getElementById('NegativeCondition').value = data.NegativeCondition;
            document.getElementById('ErrorTextId').value = data.ErrorTextId;
            document.getElementById('ScriptName').value = data.ScriptName;
            document.getElementById('ConditionComments').value = data.Comments;
        }
    </script>
</head>
<body>
    <div class="container">
        <h1>Creature Quest Loot</h1>

        <div class="messages">
            <?php
                if (!empty($errors)) {
                    echo '<div class="error"><ul>';
                    foreach ($errors as $error) {
                        echo "<li>$error</li>";
                    }
                    echo '</ul></div>';
                }

                if (!empty($success)) {
                    echo '<div class="success">' . $success . '</div>';
                }
            ?>
        </div>

        <form method="POST" action="creature_quest_loot.php?id=<?php echo $id; ?>">
            <!-- Creature Loot Template Section -->
            <div class="section">
                <h2>Creature Loot Template</h2>
                <label for="Entry">Creature Id (Entry):</label>
                <input type="text" id="Entry" name="Entry" value="<?php echo isset($creatureLoot['entry']) ? htmlspecialchars($creatureLoot['entry']) : ''; ?>" required>

                <label for="Item">Item Id (Item):</label>
                <input type="text" id="Item" name="Item" value="<?php echo isset($creatureLoot['item']) ? htmlspecialchars($creatureLoot['item']) : ''; ?>" required>

                <label for="ChanceOrQuestChance">Chance to Drop +/-:</label>
                <input type="text" id="ChanceOrQuestChance" name="ChanceOrQuestChance" value="<?php echo isset($creatureLoot['ChanceOrQuestChance']) ? htmlspecialchars($creatureLoot['ChanceOrQuestChance']) : ''; ?>">

                <label for="LootMode">Loot Mode:</label>
                <select id="LootMode" name="LootMode">
                    <option value="1" <?php echo (isset($creatureLoot['LootMode']) && $creatureLoot['LootMode'] == 1) ? 'selected' : ''; ?>>Normal</option>
                    <option value="2" <?php echo (isset($creatureLoot['LootMode']) && $creatureLoot['LootMode'] == 2) ? 'selected' : ''; ?>>Heroic</option>
                    <option value="4" <?php echo (isset($creatureLoot['LootMode']) && $creatureLoot['LootMode'] == 4) ? 'selected' : ''; ?>>Raid</option>
                </select>

                <label for="GroupId">Item Group Id (GroupId):</label>
                <input type="text" id="GroupId" name="GroupId" value="<?php echo isset($creatureLoot['GroupId']) ? htmlspecialchars($creatureLoot['GroupId']) : ''; ?>">

                <label for="MinCountOrRef">Minimum Amount Dropped +/- (MinCountOrRef):</label>
                <input type="text" id="MinCountOrRef" name="MinCountOrRef" value="<?php echo isset($creatureLoot['MinCountOrRef']) ? htmlspecialchars($creatureLoot['MinCountOrRef']) : ''; ?>">

                <label for="MaxCount">Maximum Amount Dropped (MaxCount):</label>
                <input type="text" id="MaxCount" name="MaxCount" value="<?php echo isset($creatureLoot['MaxCount']) ? htmlspecialchars($creatureLoot['MaxCount']) : ''; ?>">

                <label for="Comments">Notes (Comments):</label>
                <textarea id="Comments" name="Comments"><?php echo isset($creatureLoot['Comments']) ? htmlspecialchars($creatureLoot['Comments']) : ''; ?></textarea>
            </div>

            <!-- Conditions Section -->
            <div class="section">
                <h2>Conditions</h2>
                <label for="SourceTypeOrReferenceId">Source Type:</label>
                <select id="SourceTypeOrReferenceId" name="SourceTypeOrReferenceId">
                    <option value="1" <?php echo (isset($conditions['SourceTypeOrReferenceId']) && $conditions['SourceTypeOrReferenceId'] == 1) ? 'selected' : ''; ?>>Creature Loot</option>
                    <!-- Add more options if necessary -->
                </select>

                <label for="SourceGroup">Item Loot Template Id (SourceGroup):</label>
                <input type="text" id="SourceGroup" name="SourceGroup" value="<?php echo isset($conditions['SourceGroup']) ? htmlspecialchars($conditions['SourceGroup']) : ''; ?>">

                <label for="SourceEntry">Item Id (SourceEntry):</label>
                <input type="text" id="SourceEntry" name="SourceEntry" value="<?php echo isset($conditions['SourceEntry']) ? htmlspecialchars($conditions['SourceEntry']) : ''; ?>">

                <label for="SourceId">Source Id Default 0 (SourceId):</label>
                <input type="text" id="SourceId" name="SourceId" value="<?php echo isset($conditions['SourceId']) ? htmlspecialchars($conditions['SourceId']) : '0'; ?>">

                <label for="ElseGroup">Else Group (ElseGroup):</label>
                <input type="text" id="ElseGroup" name="ElseGroup" value="<?php echo isset($conditions['ElseGroup']) ? htmlspecialchars($conditions['ElseGroup']) : ''; ?>">

                <label for="ConditionTypeOrReference">Condition Type (ConditionTypeOrReference):</label>
                <input type="text" id="ConditionTypeOrReference" name="ConditionTypeOrReference" value="<?php echo isset($conditions['ConditionTypeOrReference']) ? htmlspecialchars($conditions['ConditionTypeOrReference']) : ''; ?>">

                <label for="ConditionTarget">Condition Target (ConditionTarget):</label>
                <input type="text" id="ConditionTarget" name="ConditionTarget" value="<?php echo isset($conditions['ConditionTarget']) ? htmlspecialchars($conditions['ConditionTarget']) : ''; ?>">

                <label for="ConditionValue1">Condition 1 (ConditionValue1):</label>
                <input type="text" id="ConditionValue1" name="ConditionValue1" value="<?php echo isset($conditions['ConditionValue1']) ? htmlspecialchars($conditions['ConditionValue1']) : $id; ?>">

                <label for="ConditionValue2">Condition 2 (ConditionValue2):</label>
                <input type="text" id="ConditionValue2" name="ConditionValue2" value="<?php echo isset($conditions['ConditionValue2']) ? htmlspecialchars($conditions['ConditionValue2']) : ''; ?>">

                <label for="ConditionValue3">Condition 3 (ConditionValue3):</label>
                <input type="text" id="ConditionValue3" name="ConditionValue3" value="<?php echo isset($conditions['ConditionValue3']) ? htmlspecialchars($conditions['ConditionValue3']) : ''; ?>">

                <label for="NegativeCondition">Negative Condition (NegativeCondition):</label>
                <input type="text" id="NegativeCondition" name="NegativeCondition" value="<?php echo isset($conditions['NegativeCondition']) ? htmlspecialchars($conditions['NegativeCondition']) : ''; ?>">

                <label for="ErrorTextId">Error Text (ErrorTextId):</label>
                <input type="text" id="ErrorTextId" name="ErrorTextId" value="<?php echo isset($conditions['ErrorTextId']) ? htmlspecialchars($conditions['ErrorTextId']) : ''; ?>">

                <label for="ScriptName">Script Name (ScriptName):</label>
                <input type="text" id="ScriptName" name="ScriptName" value="<?php echo isset($conditions['ScriptName']) ? htmlspecialchars($conditions['ScriptName']) : ''; ?>">

                <label for="ConditionComments">Notes (Comments):</label>
                <textarea id="ConditionComments" name="ConditionComments"><?php echo isset($conditions['Comments']) ? htmlspecialchars($conditions['Comments']) : ''; ?></textarea>
            </div>

            <div class="buttons">
                <input type="submit" name="save" value="Save">
                <input type="submit" name="delete" value="Delete" onclick="return confirm('Are you sure you want to delete this record?');">
                <button type="button" onclick="openSearch()">Search existing</button>
            </div>
        </form>
    </div>
</body>
</html>
