<?php
// Check if the request comes from localhost (IPv4 or IPv6)
if ($_SERVER['REMOTE_ADDR'] !== '127.0.0.1' && $_SERVER['REMOTE_ADDR'] !== '::1') {
    die('Access denied.');
}

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Start session to retrieve DB credentials
session_start();

// Check if credentials are passed via GET, if not fallback to session variables
$ip = isset($_GET['ip']) ? $_GET['ip'] : (isset($_SESSION['ip']) ? $_SESSION['ip'] : null);
$port = isset($_GET['port']) ? $_GET['port'] : (isset($_SESSION['port']) ? $_SESSION['port'] : null);
$user = isset($_GET['user']) ? $_GET['user'] : (isset($_SESSION['user']) ? $_SESSION['user'] : null);
$password = isset($_GET['password']) ? $_GET['password'] : (isset($_SESSION['password']) ? $_SESSION['password'] : null);
$dbname = isset($_GET['dbname']) ? $_GET['dbname'] : (isset($_SESSION['dbname']) ? $_SESSION['dbname'] : null);
$id = isset($_GET['id']) ? $_GET['id'] : (isset($_SESSION['id']) ? $_SESSION['id'] : null);

// Connect to the database
$mysqli = new mysqli($ip, $user, $password, $dbname, $port);
if ($mysqli->connect_error) {
    die("Connection failed: " . $mysqli->connect_error);
}

// Initialize variables with default values
$entry = '';
$class = 12; // "Quest"
$subclass = 0; // "Quest"
$name = '';
$displayid = 50453; // Default display ID
$Quality = 1; // "Common"
$Flags = 4; // "Quest"
$InventoryType = 0; // "Non-equippable"
$AllowableClass = -1; // "All"
$AllowableRace = -1; // "All"
$RequiredLevel = 0; // "None"
$bonding = 1; // "Binds when picked up"
$stackable = 1; // Default stack size
$startquest = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {

    // Handle Search Item Id
    if (isset($_POST['search_item_id'])) {
        $search_item_id = intval($_POST['search_item_id']);
        if ($search_item_id > 0) {
            $stmt = $mysqli->prepare("SELECT * FROM item_template WHERE entry = ?");
            $stmt->bind_param("i", $search_item_id);
            $stmt->execute();
            $result = $stmt->get_result();
            if ($row = $result->fetch_assoc()) {
                // Load data into variables
                $entry = $row['entry'];
                $class = $row['class'];
                $subclass = $row['subclass'];
                $name = $row['name'];
                $displayid = $row['displayid'];
                $Quality = $row['Quality'];
                $Flags = $row['Flags'];
                $InventoryType = $row['InventoryType'];
                $AllowableClass = $row['AllowableClass'];
                $AllowableRace = $row['AllowableRace'];
                $RequiredLevel = $row['RequiredLevel'];
                $bonding = $row['bonding'];
                $stackable = $row['stackable'];
                $startquest = $row['startquest'];
            } else {
                echo "Item Id not found.";
            }
            $stmt->close();
        } else {
            echo "Please enter a valid Item Id.";
        }
    }

    // Handle Search Quest Id
    elseif (isset($_POST['search_quest_id'])) {
        $search_quest_id = intval($_POST['search_quest_id']);
        if ($search_quest_id > 0) {
            $stmt = $mysqli->prepare("SELECT SourceEntry FROM conditions WHERE ConditionValue1 = ?");
            $stmt->bind_param("i", $search_quest_id);
            $stmt->execute();
            $result = $stmt->get_result();
            if ($row = $result->fetch_assoc()) {
                $entry = $row['SourceEntry'];
                // Fetch item_template data for this entry
                $stmt_item = $mysqli->prepare("SELECT * FROM item_template WHERE entry = ?");
                $stmt_item->bind_param("i", $entry);
                $stmt_item->execute();
                $result_item = $stmt_item->get_result();
                if ($item_row = $result_item->fetch_assoc()) {
                    $entry = $item_row['entry'];
                    $class = $item_row['class'];
                    $subclass = $item_row['subclass'];
                    $name = $item_row['name'];
                    $displayid = $item_row['displayid'];
                    $Quality = $item_row['Quality'];
                    $Flags = $item_row['Flags'];
                    $InventoryType = $item_row['InventoryType'];
                    $AllowableClass = $item_row['AllowableClass'];
                    $AllowableRace = $item_row['AllowableRace'];
                    $RequiredLevel = $item_row['RequiredLevel'];
                    $bonding = $item_row['bonding'];
                    $stackable = $item_row['stackable'];
                    $startquest = $item_row['startquest'];
                } else {
                    echo "No item found for the given quest.";
                }
                $stmt_item->close();
            } else {
                echo "Quest Id not found in conditions.";
            }
            $stmt->close();
        } else {
            echo "Please enter a valid Quest Id.";
        }
    }

    // Handle Save action
    elseif (isset($_POST['save'])) {
        // Get values from POST
        $entry = intval($_POST['entry']);
        $class = intval($_POST['class']);
        $subclass = intval($_POST['subclass']);
        $name = $_POST['name'];
        $displayid = intval($_POST['displayid']);
        $Quality = intval($_POST['Quality']);
        $Flags = intval($_POST['Flags']);
        $InventoryType = intval($_POST['InventoryType']);
        $AllowableClass = intval($_POST['AllowableClass']);
        $AllowableRace = intval($_POST['AllowableRace']);
        $RequiredLevel = intval($_POST['RequiredLevel']);
        $bonding = intval($_POST['bonding']);
        $stackable = intval($_POST['stackable']);
        $startquest = intval($_POST['startquest']);

        // Check if entry already exists
        $stmt = $mysqli->prepare("SELECT entry FROM item_template WHERE entry = ?");
        $stmt->bind_param("i", $entry);
        $stmt->execute();
        $stmt->store_result();
        if ($stmt->num_rows > 0) {
            // Update existing record
            $stmt_update = $mysqli->prepare("UPDATE item_template SET class=?, subclass=?, name=?, displayid=?, Quality=?, Flags=?, InventoryType=?, AllowableClass=?, AllowableRace=?, RequiredLevel=?, bonding=?, stackable=?, startquest=? WHERE entry=?");
            $stmt_update->bind_param("iisiisiiiiiiii", $class, $subclass, $name, $displayid, $Quality, $Flags, $InventoryType, $AllowableClass, $AllowableRace, $RequiredLevel, $bonding, $stackable, $startquest, $entry);
            if ($stmt_update->execute()) {
                echo "Item updated successfully.";
            } else {
                echo "Error updating item: " . $stmt_update->error;
            }
            $stmt_update->close();
        } else {
            // Insert new record
            $stmt_insert = $mysqli->prepare("INSERT INTO item_template (entry, class, subclass, name, displayid, Quality, Flags, InventoryType, AllowableClass, AllowableRace, RequiredLevel, bonding, stackable, startquest) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
            $stmt_insert->bind_param("iiisiisiiiiiii", $entry, $class, $subclass, $name, $displayid, $Quality, $Flags, $InventoryType, $AllowableClass, $AllowableRace, $RequiredLevel, $bonding, $stackable, $startquest);
            if ($stmt_insert->execute()) {
                echo "Item inserted successfully.";
            } else {
                echo "Error inserting item: " . $stmt_insert->error;
            }
            $stmt_insert->close();
        }
        $stmt->close();
    }

    // Handle Delete action
    elseif (isset($_POST['delete'])) {
        $entry = intval($_POST['entry']);
        if ($entry > 0) {
            $stmt_delete = $mysqli->prepare("DELETE FROM item_template WHERE entry = ?");
            $stmt_delete->bind_param("i", $entry);
            if ($stmt_delete->execute()) {
                echo "Item deleted successfully.";
                // Reset variables to default
                $entry = '';
                $class = 12;
                $subclass = 0;
                $name = '';
                $displayid = 50453;
                $Quality = 1;
                $Flags = 4;
                $InventoryType = 0;
                $AllowableClass = -1;
                $AllowableRace = -1;
                $RequiredLevel = 0;
                $bonding = 1;
                $stackable = 1;
                $startquest = '';
            } else {
                echo "Error deleting item: " . $stmt_delete->error;
            }
            $stmt_delete->close();
        } else {
            echo "Invalid Item Id.";
        }
    }
}
?>

<!DOCTYPE html>
<html>
<head>
    <title>Item Make</title>
</head>
<body>
    <h1>Item Make</h1>
    <!-- Search Forms -->
    <form method="post">
        <label for="search_item_id">Search Item Id:</label>
        <input type="number" name="search_item_id" id="search_item_id" required>
        <input type="submit" value="Search">
    </form>

    <form method="post">
        <label for="search_quest_id">Search Quest Id:</label>
        <input type="number" name="search_quest_id" id="search_quest_id" required>
        <input type="submit" value="Search">
    </form>

    <!-- Item Form -->
    <form method="post">
        <h2>Item Details</h2>
        <label for="entry">Item Id:</label>
        <input type="number" name="entry" id="entry" value="<?php echo htmlspecialchars($entry); ?>" required><br>

        <label for="class">Item Category:</label>
        <select name="class" id="class">
            <option value="12" <?php if ($class == 12) echo 'selected'; ?>>Quest</option>
        </select><br>

        <label for="subclass">Subclass:</label>
        <select name="subclass" id="subclass">
            <option value="0" <?php if ($subclass == 0) echo 'selected'; ?>>Quest</option>
        </select><br>

        <label for="name">Item Name:</label>
        <input type="text" name="name" id="name" value="<?php echo htmlspecialchars($name); ?>" required><br>

        <label for="displayid">Display Id:</label>
        <input type="number" name="displayid" id="displayid" value="<?php echo htmlspecialchars($displayid); ?>"><br>

        <label for="Quality">Quality:</label>
        <select name="Quality" id="Quality">
            <option value="1" <?php if ($Quality == 1) echo 'selected'; ?>>Common</option>
        </select><br>

        <label for="Flags">Flags:</label>
        <select name="Flags" id="Flags">
            <option value="4" <?php if ($Flags == 4) echo 'selected'; ?>>Quest</option>
        </select><br>

        <label for="InventoryType">Inventory Type:</label>
        <select name="InventoryType" id="InventoryType">
            <option value="0" <?php if ($InventoryType == 0) echo 'selected'; ?>>Non-equippable</option>
        </select><br>

        <label for="AllowableClass">Allowed Classes:</label>
        <select name="AllowableClass" id="AllowableClass">
            <option value="-1" <?php if ($AllowableClass == -1) echo 'selected'; ?>>All</option>
        </select><br>

        <label for="AllowableRace">Allowed Races:</label>
        <select name="AllowableRace" id="AllowableRace">
            <option value="-1" <?php if ($AllowableRace == -1) echo 'selected'; ?>>All</option>
        </select><br>

        <label for="RequiredLevel">Required Level:</label>
        <select name="RequiredLevel" id="RequiredLevel">
            <option value="0" <?php if ($RequiredLevel == 0) echo 'selected'; ?>>None</option>
        </select><br>

        <label for="bonding">Bonding:</label>
        <select name="bonding" id="bonding">
            <option value="1" <?php if ($bonding == 1) echo 'selected'; ?>>Binds when picked up</option>
        </select><br>

        <label for="stackable">Max Stack Size:</label>
        <input type="number" name="stackable" id="stackable" value="<?php echo htmlspecialchars($stackable); ?>"><br>

        <label for="startquest">Starts Quest Id:</label>
        <input type="number" name="startquest" id="startquest" value="<?php echo htmlspecialchars($startquest); ?>"><br>

        <input type="submit" name="save" value="Save">
        <input type="submit" name="delete" value="Delete">
    </form>
</body>
</html>

<?php
$mysqli->close();
?>
