<?php
// Check if the request comes from localhost (IPv4 or IPv6)
if ($_SERVER['REMOTE_ADDR'] !== '127.0.0.1' && $_SERVER['REMOTE_ADDR'] !== '::1') {
    die('Access denied.');
}

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Start session to retrieve DB credentials
session_start();

// Check if credentials are passed via GET, if not fallback to session variables
$ip = isset($_GET['ip']) ? $_GET['ip'] : (isset($_SESSION['ip']) ? $_SESSION['ip'] : null);
$port = isset($_GET['port']) ? $_GET['port'] : (isset($_SESSION['port']) ? $_SESSION['port'] : null);
$user = isset($_GET['user']) ? $_GET['user'] : (isset($_SESSION['user']) ? $_SESSION['user'] : null);
$password = isset($_GET['password']) ? $_GET['password'] : (isset($_SESSION['password']) ? $_SESSION['password'] : null);
$dbname = isset($_GET['dbname']) ? $_GET['dbname'] : (isset($_SESSION['dbname']) ? $_SESSION['dbname'] : null);
$id = isset($_GET['id']) ? $_GET['id'] : (isset($_SESSION['id']) ? $_SESSION['id'] : null);

// Verify all required fields are available
if (!$ip || !$port || !$user || !$password || !$dbname || !$id) {
    die('Missing database connection details.');
}

// Store the credentials in the session for future use
$_SESSION['ip'] = $ip;
$_SESSION['port'] = $port;
$_SESSION['user'] = $user;
$_SESSION['password'] = $password;
$_SESSION['dbname'] = $dbname;
$_SESSION['id'] = $id;

// Connect to the database
$conn = new mysqli($ip, $user, $password, $dbname, $port);
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Check if an entry and item were selected (from clickable link)
if (isset($_GET['entry']) && isset($_GET['item'])) {
    $entry = $_GET['entry'];
    $item = $_GET['item'];

    // Query creature_loot_template where entry=entry AND item=item
    $sql_cltpick = "SELECT * FROM creature_loot_template WHERE entry = ? AND item = ?";
    $stmt_cltpick = $conn->prepare($sql_cltpick);
    $stmt_cltpick->bind_param('ii', $entry, $item);
    $stmt_cltpick->execute();
    $result_cltpick = $stmt_cltpick->get_result();
    $cltpick = $result_cltpick->fetch_assoc();

    // Query conditions where SourceGroup=entry and SourceEntry=item
    $sql_cpick = "SELECT * FROM conditions WHERE SourceGroup = ? AND SourceEntry = ?";
    $stmt_cpick = $conn->prepare($sql_cpick);
    $stmt_cpick->bind_param('ii', $entry, $item);
    $stmt_cpick->execute();
    $result_cpick = $stmt_cpick->get_result();
    $cpick = $result_cpick->fetch_assoc();
}

// Query to fetch all results for listing clickable entries
$sql = "SELECT clt.entry AS CreatureId, clt.item AS ItemId, clt.ChanceOrQuestChance, clt.lootmode, clt.groupid, clt.mincountOrRef, clt.maxcount, 
        c.SourceTypeOrReferenceId, c.SourceGroup, c.SourceEntry, c.SourceId, c.ElseGroup, c.ConditionTypeOrReference, c.ConditionTarget, 
        c.ConditionValue1, c.ConditionValue2, c.ConditionValue3, c.NegativeCondition, c.ErrorTextId, c.ScriptName, c.Comment,
        ct.name AS CreatureName, it.name AS ItemName
        FROM creature_loot_template clt 
        JOIN conditions c ON c.SourceGroup = clt.entry AND c.SourceEntry = clt.item
        JOIN creature_template ct ON ct.entry = clt.entry
        JOIN item_template it ON it.entry = clt.item
        WHERE c.ConditionValue1 = ? AND clt.ChanceOrQuestChance < 1";

$stmt = $conn->prepare($sql);
$stmt->bind_param('i', $id);
$stmt->execute();
$result = $stmt->get_result();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Creature Loot Search</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 20px;
            padding: 20px;
        }
        h2 {
            color: #333;
        }
        .container {
            display: flex;
            flex-direction: column;
            gap: 20px;
        }
        .result {
            padding: 10px;
            border: 1px solid #ccc;
            margin-bottom: 10px;
            background-color: #f9f9f9;
        }
        .result a {
            display: inline-block;
            padding: 5px 10px;
            background-color: #007BFF;
            color: white;
            text-decoration: none;
            border-radius: 5px;
            margin-top: 10px;
        }
        .result a:hover {
            background-color: #0056b3;
        }
        .form-table {
            width: 100%;
            max-width: 600px;
            margin: auto;
            border-collapse: collapse;
        }
        .form-table th, .form-table td {
            padding: 10px;
            border-bottom: 1px solid #ccc;
        }
        .form-table th {
            text-align: left;
        }
        input[type="text"] {
            width: 100%;
            padding: 8px;
            box-sizing: border-box;
        }
        input[type="submit"] {
            padding: 10px 20px;
            background-color: #28a745;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
        }
        input[type="submit"]:hover {
            background-color: #218838;
        }
    </style>
</head>
<body>

<h2>Creature Loot Search Results</h2>

<div class="container">
    <?php
    // Fetch and display results as clickable links
    if ($result->num_rows > 0) {
        while ($row = $result->fetch_assoc()) {
            echo "<div class='result'>";
            echo "<strong>Creature ID:</strong> " . $row['CreatureId'] . "<br>";
            echo "<strong>Name:</strong> " . $row['CreatureName'] . "<br>";
            echo "<strong>Item ID:</strong> " . $row['ItemId'] . "<br>";
            echo "<strong>Item Name:</strong> " . $row['ItemName'] . "<br>";
            echo "<strong>Chance to Drop:</strong> " . $row['ChanceOrQuestChance'] . "<br>";
            echo "<a href='?entry=" . $row['CreatureId'] . "&item=" . $row['ItemId'] . "'>Load</a>";
            echo "</div>";
        }
    } else {
        echo "<p>No results found.</p>";
    }
    ?>
</div>

<h2>Edit Creature Loot</h2>

<form method="POST" action="save_creature_loot.php">
    <table class="form-table">
	
	    <!-- Hidden fields to pass the credentials -->
    <input type="hidden" name="ip" value="<?php echo htmlspecialchars($ip); ?>">
    <input type="hidden" name="port" value="<?php echo htmlspecialchars($port); ?>">
    <input type="hidden" name="user" value="<?php echo htmlspecialchars($user); ?>">
    <input type="hidden" name="password" value="<?php echo htmlspecialchars($password); ?>">
    <input type="hidden" name="dbname" value="<?php echo htmlspecialchars($dbname); ?>">
    <input type="hidden" name="id" value="<?php echo htmlspecialchars($id); ?>">
	
        <tr>
            <th>Creature ID</th>
            <td><input type="text" name="entry" value="<?php echo isset($cltpick['entry']) ? $cltpick['entry'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Item ID</th>
            <td><input type="text" name="item" value="<?php echo isset($cltpick['item']) ? $cltpick['item'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Chance to Drop Neg for quest</th>
            <td><input type="text" name="ChanceOrQuestChance" value="<?php echo isset($cltpick['ChanceOrQuestChance']) ? $cltpick['ChanceOrQuestChance'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Loot Mode default 1</th>
            <td><input type="text" name="lootmode" value="<?php echo isset($cltpick['lootmode']) ? $cltpick['lootmode'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Item Group ID default 0</th>
            <td><input type="text" name="groupid" value="<?php echo isset($cltpick['groupid']) ? $cltpick['groupid'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Min Count</th>
            <td><input type="text" name="mincountOrRef" value="<?php echo isset($cltpick['mincountOrRef']) ? $cltpick['mincountOrRef'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Max Count</th>
            <td><input type="text" name="maxcount" value="<?php echo isset($cltpick['maxcount']) ? $cltpick['maxcount'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Source Type default 1</th>
            <td><input type="text" name="SourceTypeOrReferenceId" value="<?php echo isset($cpick['SourceTypeOrReferenceId']) ? $cpick['SourceTypeOrReferenceId'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Item Loot Template ID</th>
            <td><input type="text" name="SourceGroup" value="<?php echo isset($cpick['SourceGroup']) ? $cpick['SourceGroup'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Item ID</th>
            <td><input type="text" name="SourceEntry" value="<?php echo isset($cpick['SourceEntry']) ? $cpick['SourceEntry'] : ''; ?>"></td>
        </tr>
		<tr>
			<th>Source Id default 0</th>
            <td><input type="text" name="SourceId" value="<?php echo isset($cpick['SourceId']) ? $cpick['SourceId'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Else Group default 0</th>
            <td><input type="text" name="ElseGroup" value="<?php echo isset($cpick['ElseGroup']) ? $cpick['ElseGroup'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Condition Type default 1</th>
            <td><input type="text" name="ConditionTypeOrReference" value="<?php echo isset($cpick['ConditionTypeOrReference']) ? $cpick['ConditionTypeOrReference'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Condition Target default 0</th>
            <td><input type="text" name="ConditionTarget" value="<?php echo isset($cpick['ConditionTarget']) ? $cpick['ConditionTarget'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Condition 1 Quest Id</th>
            <td><input type="text" name="ConditionValue1" value="<?php echo isset($cpick['ConditionValue1']) ? $cpick['ConditionValue1'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Condition 2 default 0</th>
            <td><input type="text" name="ConditionValue2" value="<?php echo isset($cpick['ConditionValue2']) ? $cpick['ConditionValue2'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Condition 3 default 0</th>
            <td><input type="text" name="ConditionValue3" value="<?php echo isset($cpick['ConditionValue3']) ? $cpick['ConditionValue3'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Negative Condition default 0</th>
            <td><input type="text" name="NegativeCondition" value="<?php echo isset($cpick['NegativeCondition']) ? $cpick['NegativeCondition'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Error Text</th>
            <td><input type="text" name="ErrorTextId" value="<?php echo isset($cpick['ErrorTextId']) ? $cpick['ErrorTextId'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Script Name</th>
            <td><input type="text" name="ScriptName" value="<?php echo isset($cpick['ScriptName']) ? $cpick['ScriptName'] : ''; ?>"></td>
        </tr>
        <tr>
            <th>Notes</th>
            <td><input type="text" name="Comment" value="<?php echo isset($cpick['Comment']) ? $cpick['Comment'] : ''; ?>"></td>
        </tr>
    </table>
    <br>
    <input type="submit" name="save" value="Save">
    <input type="submit" name="delete" value="Delete">
</form>

</body>
</html>
