<?php
// zones.php

// Path to the CSV file
$csvFile = 'Zones.csv';

// Function to read CSV and return filtered results
function searchZones($file, $searchTerm) {
    $zones = [];
    if (($handle = fopen($file, 'r')) !== false) {
        // Loop through each line in the CSV
        while (($data = fgetcsv($handle)) !== false) {
            // Check if the search term is found in column 12
            if (stripos($data[11], $searchTerm) !== false) {
                $zones[] = ['column1' => $data[0], 'column12' => $data[11]];
            }
        }
        fclose($handle);
    }

    // Sort the results alphabetically by column 12
    usort($zones, function($a, $b) {
        return strcmp($a['column12'], $b['column12']);
    });

    return $zones;
}

// Check if the search term is set
$searchTerm = isset($_POST['search']) ? $_POST['search'] : '';
$zones = $searchTerm ? searchZones($csvFile, $searchTerm) : [];
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Zone Search</title>
</head>
<body>
    <h1>Search Zones</h1>
    <form method="POST" action="zones.php">
        <label for="search">Search Name:</label>
        <input type="text" id="search" name="search" value="<?php echo htmlspecialchars($searchTerm); ?>">
        <button type="submit">Search</button>
    </form>

    <?php if (!empty($zones)): ?>
        <h2>Search Results</h2>
        <table border="1">
            <thead>
                <tr>
                    <th>Id</th>
                    <th>Name</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($zones as $zone): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($zone['column1']); ?></td>
                        <td><?php echo htmlspecialchars($zone['column12']); ?></td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    <?php elseif ($searchTerm): ?>
        <p>No results found for "<?php echo htmlspecialchars($searchTerm); ?>"</p>
    <?php endif; ?>
</body>
</html>
